pub struct ArtifactCommand {
pub cmd_id: Uuid,
pub range: SourceRange,
pub command: ModelingCmd,
pub omit_from_graph: bool,
/* private fields */
}Expand description
A command that may create or update artifacts on the TS side. Because engine commands are batched, we don’t have the response yet when these are created.
Fields
cmd_id: UuidIdentifier of the command that can be matched with its response.
range: SourceRangeThe source range that’s the boundary of calling the standard library, not necessarily the true source range of the command.
command: ModelingCmdThe engine command. Each artifact command is backed by an engine command. In the future, we may need to send information to the TS side without an engine command, in which case, we would make this field optional. Imported file commands retain paths and format but omit raw file bytes after the command has been sent to the engine.
omit_from_graph: boolWhether this command should be omitted when deriving the semantic artifact graph. Query-only commands can still be useful in command snapshots without becoming frontend selection artifacts.