pub struct RetryConfig {
pub retries: usize,
pub print_retries: bool,
}Fields
retries: usizeNumber of retries to attempt when execution results in EngineHangup or
EngineInternal.
print_retries: boolWhether to print a message to stderr when a retry is attempted.