pub struct Sketch {Show 14 fields
pub id: Uuid,
pub paths: Vec<Path>,
pub inner_paths: Vec<Path>,
pub on: SketchSurface,
pub start: BasePath,
pub tags: IndexMap<String, TagIdentifier>,
pub artifact_id: ArtifactId,
pub original_id: Uuid,
pub mirror: Option<Uuid>,
pub clone: Option<Uuid>,
pub synthetic_jump_path_ids: Vec<Uuid>,
pub units: UnitLength,
pub meta: Vec<Metadata>,
pub is_closed: ProfileClosed,
}Fields
id: UuidThe id of the sketch (this will change when the engine’s reference to it changes).
paths: Vec<Path>The paths in the sketch. Only paths on the “outside” i.e. the perimeter. Does not include paths “inside” the profile (for example, edges made by subtracting a profile)
inner_paths: Vec<Path>Inner paths, resulting from subtract2d to carve profiles out of the sketch.
on: SketchSurfaceWhat the sketch is on (can be a plane or a face).
start: BasePathThe starting path.
Tag identifiers that have been declared in this sketch.
artifact_id: ArtifactIdThe original id of the sketch. This stays the same even if the sketch is is sketched on face etc.
original_id: Uuidmirror: Option<Uuid>If the sketch includes a mirror.
clone: Option<Uuid>If the sketch is a clone of another sketch.
synthetic_jump_path_ids: Vec<Uuid>Synthetic pen-jump paths inserted to replay disconnected segment selections.
units: UnitLengthmeta: Vec<Metadata>Metadata.
is_closed: ProfileClosedHas the profile been closed? If not given, defaults to yes, closed explicitly.