pub fn arc_arc_intersection(
arc1_center: Coords2d,
arc1_start: Coords2d,
arc1_end: Coords2d,
arc2_center: Coords2d,
arc2_start: Coords2d,
arc2_end: Coords2d,
epsilon: f64,
) -> Option<Coords2d>Expand description
Helper to calculate one intersection between two arcs (if any).
This is kept for compatibility with existing call sites/tests that expect a single optional intersection.