pub struct EditDistanceConstraintLabelPositionOptions {
pub anchor_segment_ids: Vec<ObjectId>,
pub commit_solved_initial_guesses: bool,
}Expand description
Options for a distance-constraint label edit during sketch dragging.
Fields
anchor_segment_ids: Vec<ObjectId>Edited scene objects to keep anchored while previewing the label edit.
commit_solved_initial_guesses: boolWhether solver-updated initial guesses should be written back to KCL.