Skip to main contentModule lint
Source - checks
- Discovered
- Specific discovered lint rule Violation of a particular Finding.
- Finding
- Abstract lint problem type.
- FindingFamily
- Abstract lint problem type.
- Rule
- Check the provided AST for any found rule violations.
- lint_and_fix_all
- Lint, and try to apply all suggestions.
Returns the new source code, and any lints without suggestions.
- lint_and_fix_families
- Lint, and try to apply all suggestions.
Returns the new source code, and any lints without suggestions.