pub trait Rule<'a> {
// Required method
fn check(
&self,
node: Node<'a>,
prog: &AstNode<Program>,
) -> Result<Vec<Discovered>>;
}Expand description
Check the provided AST for any found rule violations.
The Rule trait is automatically implemented for a few other types, but it can also be manually implemented as required.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".