Module edge

Module edge 

Edge helper functions.

Structs

UnresolvedEdgeSpecifier
Edge specifier payload (sideFaces, endFaces, index) as passed from KCL. Stored in BoundedEdge and resolved to kcmc::shared::EdgeSpecifier in blend().

Enums

TagOrUuid
Tag or UUID for use in an unresolved edge specifier (resolved to face UUIDs in blend).

Functions

get_bounded_edge
get_common_edge
Get the shared edge between two faces.
get_next_adjacent_edge
Get the next adjacent edge to the edge given.
get_opposite_edge
Get the opposite edge to the edge given.
get_previous_adjacent_edge
Get the previous adjacent edge to the edge given.