Module string

Module string 

Standard library string operations.

Functions

is_equal
Compare two strings for equality.
lowercase
Convert all cased characters in a string to lowercase.
number_to_string
Convert a number to human-readable text.
trim
Remove whitespace from the start and end of a string.
trim_end
Remove whitespace from the end of a string.
trim_start
Remove whitespace from the start of a string.
uppercase
Convert all cased characters in a string to uppercase.