Standard library appearance.
Functions
- blend
- Create a new surface that blends between two edges of separate surface bodies
- delete_
face - flip_
surface - Flips the orientation of a surface, swapping which side is the front and which is the reverse.
- is_
solid - Check if this object is a solid or not.
- is_
surface - Check if this object is a surface or not.