Module view

Module view 

Standard library functions for named views.

Functions

directed
Create a camera view that looks along a custom direction.
named
Create a named view: a camera paired with the objects it shows or hides.
oriented
Create a camera view that looks at the model from a standard orientation.