pub struct AstProgram {
pub body: Vec<BodyItem>,
pub non_code_meta: NonCodeMeta,
pub shebang: Option<Node<Shebang>>,
pub inner_attrs: NodeList<Annotation>,
pub digest: Option<[u8; 32]>,
}Expand description
A KCL program top level, or function body.
Fields
body: Vec<BodyItem>non_code_meta: NonCodeMetashebang: Option<Node<Shebang>>inner_attrs: NodeList<Annotation>digest: Option<[u8; 32]>Implementations
Sourceimpl Program
impl Program
Sourcepub fn ends_with_expr(&self) -> bool
pub fn ends_with_expr(&self) -> bool
Is the last body item an expression?
Sourcepub fn get_body_item_for_position(&self, pos: usize) -> Option<&BodyItem>
pub fn get_body_item_for_position(&self, pos: usize) -> Option<&BodyItem>
Returns the body item that includes the given character position.
Sourcepub fn get_mut_body_item_for_position(
&mut self,
pos: usize,
) -> Option<&mut BodyItem>
pub fn get_mut_body_item_for_position( &mut self, pos: usize, ) -> Option<&mut BodyItem>
Returns the body item that includes the given character position.
Sourcepub fn get_expr_for_position(&self, pos: usize) -> Option<&Expr>
pub fn get_expr_for_position(&self, pos: usize) -> Option<&Expr>
Returns an Expr that includes the given character position.
This is a bit more recursive than get_body_item_for_position.
Sourcepub fn has_import_statements(&self) -> bool
pub fn has_import_statements(&self) -> bool
Checks if the ast has any import statements.
pub fn in_comment(&self, pos: usize) -> bool
pub fn get_lsp_folding_ranges(&self) -> Vec<FoldingRange>
Sourcepub fn rename_symbol(&mut self, new_name: &str, pos: usize) -> bool
pub fn rename_symbol(&mut self, new_name: &str, pos: usize) -> bool
Rename the variable declaration at the given position.
Returns whether anything was actually renamed. Only top-level declarations, import aliases, and parameters of top-level functions are supported; a position inside a nested declaration (e.g. a local in a function body or an if-expression arm) renames nothing and returns false.
Sourcepub fn replace_variable(
&mut self,
name: &str,
declarator: Node<VariableDeclarator>,
)
pub fn replace_variable( &mut self, name: &str, declarator: Node<VariableDeclarator>, )
Replace a variable declaration with the given name with a new one.
Sourcepub fn replace_value(&mut self, source_range: SourceRange, new_value: Expr)
pub fn replace_value(&mut self, source_range: SourceRange, new_value: Expr)
Replace a value with the new value, use the source range for matching the exact value.
Sourcepub fn get_variable(&self, name: &str) -> Option<Definition<'_>>
pub fn get_variable(&self, name: &str) -> Option<Definition<'_>>
Get the variable declaration with the given name.
Sourceimpl Program
impl Program
pub fn recast_top( &self, options: &FormatOptions, indentation_level: usize, ) -> String
pub fn recast( &self, buf: &mut String, options: &FormatOptions, indentation_level: usize, )