pub struct ExecOutcome {
pub variables: IndexMap<String, KclValue>,
pub operations: Vec<Operation>,
pub artifact_graph: ArtifactGraph,
pub scene_objects: Vec<Object>,
pub source_range_to_object: BTreeMap<SourceRange, ObjectId>,
pub var_solutions: Vec<(SourceRange, Number)>,
pub issues: Vec<CompilationIssue>,
pub filenames: IndexMap<ModuleId, ModulePath>,
pub default_planes: Option<DefaultPlanes>,
}Expand description
Outcome of executing a program. This is used in TS.
Fields
variables: IndexMap<String, KclValue>Variables in the top-level of the root module. Note that functions will have an invalid env ref.
operations: Vec<Operation>Operations that have been performed in execution order, for display in the Feature Tree.
artifact_graph: ArtifactGraphOutput artifact graph.
scene_objects: Vec<Object>Objects in the scene, created from execution.
source_range_to_object: BTreeMap<SourceRange, ObjectId>Map from source range to object ID for lookup of objects by their source range.
var_solutions: Vec<(SourceRange, Number)>issues: Vec<CompilationIssue>Non-fatal errors and warnings.
filenames: IndexMap<ModuleId, ModulePath>File Names in module Id array index order
default_planes: Option<DefaultPlanes>The default planes.
Implementations
Sourceimpl ExecOutcome
impl ExecOutcome
pub fn scene_object_by_id(&self, id: ObjectId) -> Option<&Object>
Sourcepub fn errors(&self) -> impl Iterator<Item = &CompilationIssue>
pub fn errors(&self) -> impl Iterator<Item = &CompilationIssue>
Returns non-fatal errors. Warnings are not included.
Sourcepub fn sketch_constraint_report(&self) -> SketchConstraintReport
pub fn sketch_constraint_report(&self) -> SketchConstraintReport
Analyze all sketches in the execution result and group them by constraint status (fully, under, or over constrained).
Each segment in a sketch computes its own freedom by looking up the freedom of its constituent points. Owned points (belonging to a Line/Arc/Circle) are skipped to avoid double-counting.