Program

Struct Program 

pub struct Program {
    pub ast: Node<Program>,
    pub original_file_contents: String,
}

Fields

ast: Node<Program>original_file_contents: String

Implementations

Source

impl Program

pub fn parse( input: &str, ) -> Result<(Option<Program>, Vec<CompilationIssue>), KclError>

pub fn parse_no_errs(input: &str) -> Result<Program, KclError>

pub fn compute_digest(&mut self) -> [u8; 32]

pub fn meta_settings(&self) -> Result<Option<MetaSettings>, KclError>

Get the meta settings for the kcl file from the annotations.

pub fn change_default_units( &self, length_units: Option<UnitLength>, ) -> Result<Self, KclError>

Change the meta settings for the kcl file.

pub fn change_experimental_features( &self, warning_level: Option<WarningLevel>, ) -> Result<Self, KclError>

pub fn is_empty_or_only_settings(&self) -> bool

pub fn lint_all(&self) -> Result<Vec<Discovered>, Error>

pub fn lint<'a>(&'a self, rule: impl Rule<'a>) -> Result<Vec<Discovered>, Error>

pub fn node_path_from_range( &self, cached_body_items: usize, range: SourceRange, ) -> Option<NodePath>

pub fn fill_node_paths(self) -> Program

Fill node paths and consume the input so that the program without paths isn’t accidentally used. Filling node paths happens automatically during parsing. Calling this is only needed after the caller invalidates the node paths such as by mutating an AST or by making a round-trip through serialization.

pub fn recast(&self) -> String

pub fn recast_with_options(&self, options: &FormatOptions) -> String

pub fn empty() -> Self

Create an empty program.