Module test_server

Module test_server 

Types used to send data to the test server.

Structs

Glb
single-file binary blob containing mesh and brep
RequestBody

Functions

execute
Executes a KCL program. Only returns success or error.
execute_and_export_step
execute_and_snapshot_legacy_sim_test
Executes a kcl program and takes a snapshot of the result. This returns the bytes of the snapshot.
execute_and_snapshot_no_auth
execute_locally_and_render_on_engine
Execute the kcl and ask the engine to render an image 2d kcl files can’t be exported for local render Fails if geometry_only = true
new_context
new_context_engine_graphics