Module exec

Module exec 

Structs

ArtifactCommand
A command that may create or update artifacts on the TS side. Because engine commands are batched, we don’t have the response yet when these are created.
DefaultPlanes
IdGenerator
A generator for ArtifactIds that can be stable across executions.
RetryConfig
Sketch

Enums

KclValue
Any KCL value.
NumericType
Operation
A CAD modeling operation for display in the feature tree, AKA operations timeline.
PlaneKind
Kind of plane.
UnitType
WarningLevel

Functions

execute_with_retries
If execution results in EngineHangup or EngineInternal, retry.