Structs
- Artifact
Command - A command that may create or update artifacts on the TS side. Because engine commands are batched, we don’t have the response yet when these are created.
- Default
Planes - IdGenerator
- A generator for ArtifactIds that can be stable across executions.
- Retry
Config - Sketch
Enums
- KclValue
- Any KCL value.
- Numeric
Type - Operation
- A CAD modeling operation for display in the feature tree, AKA operations timeline.
- Plane
Kind - Kind of plane.
- Unit
Type - Warning
Level
Functions
- execute_
with_ retries - If execution results in
EngineHanguporEngineInternal, retry.