Edge helper functions.
Structs
- Unresolved
Edge Specifier - Edge specifier payload (sideFaces, endFaces, index) as passed from KCL. Stored in BoundedEdge and resolved to
kcmc::shared::EdgeSpecifierin blend().
Enums
- TagOr
Uuid - Tag or UUID for use in an unresolved edge specifier (resolved to face UUIDs in blend).
Functions
- get_
bounded_ edge - get_
common_ edge - Get the shared edge between two faces.
- get_
next_ adjacent_ edge - Get the next adjacent edge to the edge given.
- get_
opposite_ edge - Get the opposite edge to the edge given.
- get_
previous_ adjacent_ edge - Get the previous adjacent edge to the edge given.