Standard library string operations.
Functions
- is_
equal - Compare two strings for equality.
- lowercase
- Convert all cased characters in a string to lowercase.
- number_
to_ string - Convert a number to human-readable text.
- trim
- Remove whitespace from the start and end of a string.
- trim_
end - Remove whitespace from the end of a string.
- trim_
start - Remove whitespace from the start of a string.
- uppercase
- Convert all cased characters in a string to uppercase.