pub struct ExecutorSettings {
pub highlight_edges: bool,
pub enable_ssao: bool,
pub show_grid: bool,
pub replay: Option<String>,
pub project_directory: Option<TypedPath>,
pub current_file: Option<TypedPath>,
pub fixed_size_grid: bool,
pub skip_artifact_graph: bool,
pub heartbeats: Option<u64>,
}Expand description
The executor settings.
Fields
highlight_edges: boolHighlight edges of 3D objects?
enable_ssao: boolWhether or not Screen Space Ambient Occlusion (SSAO) is enabled.
show_grid: boolShow grid?
replay: Option<String>Should engine store this for replay? If so, under what name?
project_directory: Option<TypedPath>The directory of the current project. This is used for resolving import paths. If None is given, the current working directory is used.
current_file: Option<TypedPath>This is the path to the current file being executed. We use this for preventing cyclic imports.
fixed_size_grid: boolWhether or not to automatically scale the grid when user zooms.
skip_artifact_graph: boolSkip sending the engine messages that are only needed to build the artifact graph. When this is true, the artifact graph will be incomplete. So you should only use this option if you know you don’t need the artifact graph or anything that depends on it. In that case, skipping these commands can make execution slightly faster.
heartbeats: Option<u64>If Some(N), sends a heartbeat to keep the WebSocket active, every N seconds. If None, no heartbeats will be sent.
Implementations
Sourceimpl ExecutorSettings
impl ExecutorSettings
Sourcepub fn with_current_file(&mut self, current_file: TypedPath)
pub fn with_current_file(&mut self, current_file: TypedPath)
Add the current file path to the executor settings.