Types used to send data to the test server.
Structs
- Glb
- single-file binary blob containing mesh and brep
- Request
Body
Functions
- execute
- Executes a KCL program. Only returns success or error.
- execute_
and_ export_ step - execute_
and_ snapshot_ legacy_ sim_ test - Executes a kcl program and takes a snapshot of the result. This returns the bytes of the snapshot.
- execute_
and_ snapshot_ no_ auth - execute_
locally_ and_ render_ on_ engine - Execute the kcl and ask the engine to render an image 2d kcl files can’t be exported for local render Fails if geometry_only = true
- new_
context - new_
context_ engine_ graphics